@@ -11,7 +11,7 @@
 #source("util.args.R")
 
 # function to calculate affinities with mosaic of basis species
-mosaic <- function(bases, bases2 = NULL, blend = TRUE, ...) {
+mosaic <- function(bases, bases2 = NULL, blend = TRUE, stable = list(), ...) {
 
   # argument recall 20190120
   # if the first argument is the result from a previous mosaic() calculation,
@@ -42,7 +42,7 @@ mosaic <- function(bases, bases2 = NULL, blend = TRUE, ...) {
       hasbases2 <- TRUE
     }
     otherargs <- list(...)
-    allargs <- c(list(bases = bases, blend = blend), otherargs)
+    allargs <- c(list(bases = bases, blend = blend, stable = stable), otherargs)
     out <- do.call(mosaic, allargs)
     # replace A.bases (affinity calculations for all groups of basis species) with backwards-compatbile A.bases and A.bases2
     if(hasbases2) A.bases2 <- out$A.bases[[2]]
@@ -63,23 +63,26 @@ mosaic <- function(bases, bases2 = NULL, blend = TRUE, ...) {
   ibasis0 <- match(ispecies0, basis0$ispecies)
   # quit if starting basis species are not present
   ina <- is.na(ibasis0)
-  if(any(ina)) stop("the starting basis does not have ", paste(bases[ina], collapse = ", "))
+  if(any(ina)) {
+    names0 <- unlist(lapply(bases, "[", 1))
+    stop("the starting basis does not have ", paste(names0[ina], collapse = " and "))
+  }
 
   # run subcrt() calculations for all basis species and formed species 20190131
   # this avoids repeating the calculations in different calls to affinity()
   # add all the basis species here - the formed species are already present
-  lapply(bases, species)
+  lapply(bases, species, add = TRUE)
   sout <- affinity(..., return.sout = TRUE)
 
   # calculate affinities of the basis species themselves
   A.bases <- list()
   for(i in 1:length(bases)) {
     message("mosaic: calculating affinities of basis species group ", i, ": ", paste(bases[[i]], collapse=" "))
-    species(delete = TRUE)
     mysp <- species(bases[[i]])
     # 20191111 include only aq species in total activity
     iaq <- mysp$state == "aq"
-    species(which(iaq), basis0$logact[ibasis0[i]])
+    # use as.numeric in case a buffer is active 20201014
+    if(any(iaq)) species(which(iaq), as.numeric(basis0$logact[ibasis0[i]]))
     A.bases[[i]] <- suppressMessages(affinity(..., sout = sout))
   }
 
@@ -106,14 +109,15 @@ mosaic <- function(bases, bases2 = NULL, blend = TRUE, ...) {
 
   # calculate equilibrium mole fractions for each group of basis species
   group.fraction <- list()
-  if(blend) {
-    E.bases <- list()
-    for(i in 1:length(A.bases)) {
+  blend <- rep(blend, length(A.bases))
+  E.bases <- list()
+  for(i in 1:length(A.bases)) {
+    if(blend[i] & is.null(stable[i][[1]])) {
       # this isn't needed (and doesn't work) if all the affinities are NA 20180925
       if(any(!sapply(A.bases[[1]]$values, is.na))) {
         # 20190504: when equilibrating the changing basis species, use a total activity equal to the activity from the basis definition
         # 20191111 use equilibrate(loga.balance = ) instead of setting activities in species definition
-        e <- equilibrate(A.bases[[i]], loga.balance = basis0$logact[ibasis0[i]])
+        e <- equilibrate(A.bases[[i]], loga.balance = as.numeric(basis0$logact[ibasis0[i]]))
         # exponentiate to get activities then divide by total activity
         a.equil <- lapply(e$loga.equil, function(x) 10^x)
         a.tot <- Reduce("+", a.equil)
@@ -123,16 +127,20 @@ mosaic <- function(bases, bases2 = NULL, blend = TRUE, ...) {
       } else {
         group.fraction[[i]] <- A.bases[[i]]$values
       }
-    }
-  } else {
-    # for blend = FALSE, we just look at whether
-    # a basis species predominates within its group
-    for(i in 1:length(A.bases)) {
-      d <- diagram(A.bases[[i]], plot.it = FALSE, limit.water = FALSE)
+    } else {
+      # for blend = FALSE, we just look at whether
+      # a basis species predominates within its group
+      if(is.null(stable[i][[1]])) {
+        d <- diagram(A.bases[[i]], plot.it = FALSE, limit.water = FALSE)
+        predom <- d$predominant
+      } else {
+        # get the stable species from the argument 20200715
+        predom <- stable[i][[1]]
+      }
       group.fraction[[i]] <- list()
       for(j in 1:length(bases[[i]])) {
         # if a basis species predominates, it has a mole fraction of 1, or 0 otherwise
-        yesno <- d$predominant
+        yesno <- predom
         yesno[yesno != j] <- 0
         yesno[yesno == j] <- 1
         group.fraction[[i]][[j]] <- yesno
@@ -181,6 +189,5 @@ mosaic <- function(bases, bases2 = NULL, blend = TRUE, ...) {
   # for argument recall, include all arguments in output 20190120
   allargs <- c(list(bases = bases, blend = blend), list(...))
   # return the affinities for the species and basis species
-  if(blend) return(list(fun = "mosaic", args = allargs, A.species = A.species, A.bases = A.bases, E.bases = E.bases))
-  else return(list(fun = "mosaic", args = allargs, A.species = A.species, A.bases = A.bases))
+  return(list(fun = "mosaic", args = allargs, A.species = A.species, A.bases = A.bases, E.bases = E.bases))
 }
