@@ -1,10 +1,10 @@
 # CHNOSZ/demo/contour.R
 # gold solubility contours on logfO2-pH diagram
-# 20181107 initial version
-# 20190415 cleanup for demo
-
 # After Williams-Jones et al., 2009, Fig. 3
 # doi:10.2113/gselements.5.5.281
+# 20181107 initial version
+# 20190415 cleanup for demo
+library(CHNOSZ)
 
 # define temperature (degrees C), pressure (bar), grid resolution
 T <- 250
@@ -24,14 +24,14 @@ basis("Cl-", log10(NaCl$m_Cl))
 # calculate affinity with changing basis species
 bases <- c("H2S", "HS-", "HSO4-", "SO4-2")
 m <- mosaic(bases, pH = c(2, 10, res), O2 = c(-41, -29, res), T = T, P = P, IS = NaCl$IS, blend = blend)
+# show predominance fields
+diagram(m$A.bases, col = "red", col.names = "red", lty = 2, italic = TRUE)
+diagram(m$A.species, add=TRUE, col = "blue", col.names = "blue", lwd = 2, bold = TRUE)
 # calculate and plot solubility
 s <- solubility(m$A.species)
 # convert to ppb
 s <- convert(s, "ppb")
-diagram(s, type="loga.balance", levels = c(1, 10, 100, 1000))
-# show predominance fields
-diagram(m$A.bases, add=TRUE, col = "red", col.names = "red", limit.water = FALSE, lty = 2, italic = TRUE)
-diagram(m$A.species, add=TRUE, col = "blue", col.names = "blue", limit.water = FALSE, lwd = 2, bold = TRUE)
+diagram(s, type = "loga.balance", levels = c(1, 10, 100, 1000), add = TRUE)
 # add legend and title
 dP <- describe.property(c("T", "P"), c(250, 500))
 legend("top", dP, bty = "n", inset = c(0, 0.06))
