@@ -1,8 +1,10 @@
 ## steps in calculation of chemical activities of two proteins
 ## in metastable equilibrium, after Dick and Shock, 2011
+library(CHNOSZ)
+
 protein <- pinfo(c("CSG_METVO", "CSG_METJA"))
 # use superseded properties of [Met], [Gly], and [UPBB] (Dick et al., 2006)
-add.obigt("OldAA")
+add.OBIGT("OldAA")
 # set up the basis species to those used in DS11
 basis("CHNOS+")
 # note this yields logaH2 = -4.657486
